@@ -6,5 +6,5 @@ class JobScoring():
         self.client = api
 
     # TODO add job scoring
-    def list(self):
-        return
\ No newline at end of file
+    def get(self):
+        return
