@@ -1,18 +1,20 @@
 """Profile related calls."""
 import json
-import time
 from .feedback import ProfileFeedback
-from .attachments import ProfileAttachments
+from .attachment import ProfileAttachments
+from .tag import ProfileTags
+from .metadata import ProfileMetadatas
 from .parsing import ProfileParsing
 from .revealing import ProfileRevealing
 from .embedding import ProfileEmbedding
+from .searching import ProfileSearching
 from .scoring import ProfileScoring
 from .reasoning import ProfileReasoning
+from .importer import ProfileImporter
+from .exporter import ProfileExporter
 
 from .validator import *
 
-TIMESTAMP_NOW = time.time()
-
 
 class Profile(object):
     """
@@ -53,12 +55,17 @@ class Profile(object):
         """
         self.client = client
         self.feedback = ProfileFeedback(self.client)
-        self.attachments = ProfileAttachments(self.client)
+        self.attachment = ProfileAttachments(self.client)
+        self.tag = ProfileTags(self.client)
+        self.metadata = ProfileMetadatas(self.client)
         self.parsing = ProfileParsing(self.client)
         self.revealing = ProfileRevealing(self.client)
         self.embedding = ProfileEmbedding(self.client)
+        self.searching = ProfileSearching(self.client)
         self.scoring = ProfileScoring(self.client)
         self.reasoning = ProfileReasoning(self.client)
+        self.importer = ProfileImporter(self.client)
+        self.exporter = ProfileExporter(self.client)
 
     def add_json(self, source_id, profile_json, profile_reference=None, profile_labels=[], profile_tags=[],
                  profile_metadatas=[], timestamp_reception=None):
@@ -79,7 +86,7 @@ class Profile(object):
         response = self.client.post("profile", data=payload)
         return response.json()
 
-    def add_file(self, source_id, profile_file, profile_content_type=None, profile_reference='', profile_labels=[],
+    def add_file(self, source_id, profile_file, profile_content_type=None, profile_reference=None, profile_labels=[],
                  profile_tags=[], profile_metadatas=[], sync_parsing=0, timestamp_reception=None):
         """
         Add a profile resume to a sourced id.
@@ -149,61 +156,3 @@ class Profile(object):
             'fail': failed_upload
         }
         return result
-
-    def search(self, source_ids=None, seniority="all", stage=None, date_start="1494539999", date_end=TIMESTAMP_NOW,
-               page=1, limit=30, sort_by='date_reception', order_by=None):
-        """
-        Retreive all profiles that match the query param.
-
-        Args:
-            date_end:   <string> REQUIRED (default to timestamp of now)
-                        profiles' last date of reception
-            date_start: <string> REQUIRED (default to "1494539999")
-                        profiles' first date of reception
-            limit:      <int> (default to 30)
-                        number of fetched profiles/page
-            page:       <int> REQUIRED default to 1
-                        number of the page associated to the pagination
-            seniority:  <string> defaut to "all"
-                        profiles' seniority ("all", "senior", "junior")
-            sort_by:    <string>
-            source_ids: <array of strings> REQUIRED
-            stage:      <string>
-
-        Returns
-            Retrieve the profiles data as <dict>
-
-        """
-        query_params = {"source_ids": json.dumps(validate_source_ids(source_ids)), "stage": validate_stage(stage),
-                        "seniority": validate_seniority(seniority),
-                        "date_end": validate_timestamp(date_end, "date_end"),
-                        "date_start": validate_timestamp(date_start, "date_start"), "limit": validate_limit(limit),
-                        "page": validate_page(page), "sort_by": validate_sort_by(sort_by),
-                        "order_by": validate_order_by(order_by)}
-
-        response = self.client.get("profiles/searching", query_params)
-        return response.json()
-
-    def get(self, source_id=None, profile_id=None, profile_reference=''):
-        """
-        Retrieve the profile information associated with profile id.
-
-        Args:
-            source_id:              <string>
-                                    source id
-            profile_id:             <string>
-                                    profile id
-            profile_reference:      <string>
-                                    profile_reference
-
-        Returns
-            profile information
-
-        """
-        query_params = {"source_id": validate_source_ids(source_id)}
-        if profile_id:
-            query_params["profile_id"] = validate_profile_id(profile_id)
-        if profile_reference:
-            query_params["profile_reference"] = validate_profile_reference(profile_reference)
-        response = self.client.get('profile', query_params)
-        return response.json()
