@@ -1,6 +1,6 @@
 """Some constants for tests."""
 
-API_SECRET = "ask_cbe04b31bde4c51c6bf0d320d4b285c2"
+API_SECRET = "secret_api_key    "
 
 WEBHOOK_SECRET = 'totaly_a_valid_secret_key'
 
